aboutsummaryrefslogtreecommitdiffstats
path: root/res/res_jabber.c
diff options
context:
space:
mode:
authoroej <oej@f38db490-d61c-443f-a65b-d21fe96a405b>2007-06-07 09:55:13 +0000
committeroej <oej@f38db490-d61c-443f-a65b-d21fe96a405b>2007-06-07 09:55:13 +0000
commite653feb58191008abff9effad9d6f55a76501dfb (patch)
treef0b1786d7937389e45348d5b7acc9535a0a8a83d /res/res_jabber.c
parent60d857085bec33f2b5f3550cde8d63bb743d1fd6 (diff)
Ok, we found out that this is not about if you have any *active* clients using TLS, but
if you have initialized TLS at all during the lifetime of the module. So if you reload to disable TLS, it won't help. git-svn-id: http://svn.digium.com/svn/asterisk/branches/1.4@68028 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'res/res_jabber.c')
-rw-r--r--res/res_jabber.c20
1 files changed, 7 insertions, 13 deletions
diff --git a/res/res_jabber.c b/res/res_jabber.c
index fe895db8b..5059484ca 100644
--- a/res/res_jabber.c
+++ b/res/res_jabber.c
@@ -168,11 +168,11 @@ static char *ajistatus_descrip =
" If not in roster variable will = 7\n";
struct aji_client_container clients;
-
struct aji_capabilities *capabilities = NULL;
/*! \brief Global flags, initialized to default values */
static struct ast_flags globalflags = { AJI_AUTOPRUNE | AJI_AUTOREGISTER };
+static int tls_initialized = FALSE;
/*!
* \brief Deletes the aji_client data structure.
@@ -502,10 +502,11 @@ static int aji_act_hook(void *data, int type, iks *node)
switch (type) {
case IKS_NODE_START:
if (client->usetls && !iks_is_secure(client->p)) {
- if (iks_has_tls())
+ if (iks_has_tls()) {
iks_start_tls(client->p);
- else
- ast_log(LOG_ERROR, "gnuTLS not installed.\n");
+ tls_initialized = TRUE;
+ } else
+ ast_log(LOG_ERROR, "gnuTLS not installed. You need to recompile the Iksemel library with gnuTLS support\n");
break;
}
if (!client->usesasl) {
@@ -2416,20 +2417,13 @@ static int aji_reload()
static int unload_module(void)
{
- int module_uses_tls = FALSE;
- /* Check if any client use TLS. If that's the case, we can't unload this
+ /* Check if TLS is initialized. If that's the case, we can't unload this
module due to a bug in the iksemel library that will cause a crash or
a deadlock. We're trying to find a way to handle this, but in the meantime
we will simply refuse to die...
*/
- ASTOBJ_CONTAINER_TRAVERSE(&clients, 1, {
- ASTOBJ_RDLOCK(iterator);
- if (iterator->usetls)
- module_uses_tls = TRUE;
- ASTOBJ_UNLOCK(iterator);
- });
- if (module_uses_tls) {
+ if (tls_initialized) {
ast_log(LOG_ERROR, "Module can't be unloaded due to a bug in the Iksemel library when using TLS.\n");
return 1; /* You need a forced unload to get rid of this module */
}